@@ -1,10 +1,11 @@
 #ifndef _UNISTD_H
 #define _UNISTD_H
 
+FILE_LICENCE ( GPL2_OR_LATER );
+
 #include <stddef.h>
 #include <stdarg.h>
 
-unsigned int sleep ( unsigned int seconds );
 extern int execv ( const char *command, char * const argv[] );
 
 /**
@@ -22,10 +23,21 @@ extern int execv ( const char *command, char * const argv[] );
 		rc;							\
 	} )
 
-void udelay(unsigned int usecs);
-void mdelay(unsigned int msecs);
+/* Pick up udelay() */
+#include <gpxe/timer.h>
 
-#define usleep(x) udelay(x)
+/*
+ * sleep() prototype is defined by POSIX.1.  usleep() prototype is
+ * defined by 4.3BSD.  udelay() and mdelay() prototypes are chosen to
+ * be reasonably sensible.
+ *
+ */
 
+extern unsigned int sleep ( unsigned int seconds );
+extern void mdelay ( unsigned long msecs );
+
+static inline __always_inline void usleep ( unsigned long usecs ) {
+	udelay ( usecs );
+}
 
 #endif /* _UNISTD_H */
